/**
 *
 * Openutils testing library (http://lab.openmindonline.it/products/testing.html)
 * Framework that helps to simplify unit testing coding
 * Copyright (C)2005 - 2009, Openmind S.r.l. http://www.openmindonline.it
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/lgpl-2.1.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package it.openutils.testing;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;


/**
 * Utility methods for checking dates in unit tests.
 * @author fgiust
 * @version $Id: DateAssert.java 1301 2009-08-25 09:41:04Z mmunaretto $
 */
public final class DateAssert
{

    private static DateFormat df = new SimpleDateFormat("yyyyMMdd");

    private static DateFormat dtf = new SimpleDateFormat("yyyyMMdd HH:mm");

    /**
     * Don't instantiate.
     */
    private DateAssert()
    {
        // unused
    }

    /**
     * @param expectedDateAsString
     * @param date
     * @param format
     * @throws AssertionError
     */
    private static void performComparison(String expectedDateAsString, Date date, DateFormat format)
        throws AssertionError
    {
        Date expected;

        try
        {
            synchronized (format)
            {
                expected = format.parse(expectedDateAsString);
            }
        }
        catch (ParseException e)
        {
            throw new IllegalArgumentException("Unparseable date String: [" + expectedDateAsString + "]");
        }

        if (date == null)
        {
            throw new AssertionError("Date is null");
        }

        String expDate;
        String actDate;

        synchronized (format)
        {
            expDate = format.format(expected);
            actDate = format.format(date);
        }

        if (!expDate.equals(actDate))
        {
            throw new AssertionError("Expected <" + expDate + ">, actual <" + actDate + ">");
        }
    }

    /**
     * Asserts that two dates are equal.
     * @param expectedDateAsString date formatted as "YYYYMMDD"
     * @param date actual date
     * @throws IllegalArgumentException if <code>expectedDateAsString</code> is not a valid date format
     */
    public static void dateEqual(String expectedDateAsString, Calendar date) throws IllegalArgumentException
    {
        performComparison(expectedDateAsString, date.getTime(), df);
    }

    /**
     * Asserts that two dates are equal.
     * @param expectedDateAsString date formatted as "YYYYMMDD"
     * @param date actual date
     * @throws IllegalArgumentException if <code>expectedDateAsString</code> is not a valid date format
     */
    public static void dateEqual(String expectedDateAsString, Date date) throws IllegalArgumentException
    {
        performComparison(expectedDateAsString, date, df);
    }

    /**
     * Asserts that two dates are equal.
     * @param expectedDateAsString date formatted as "yyyyMMdd HH:mm"
     * @param date actual date
     * @throws IllegalArgumentException if <code>expectedDateAsString</code> is not a valid date format
     */
    public static void dateTimeEqual(String expectedDateAsString, Date date) throws IllegalArgumentException
    {
        performComparison(expectedDateAsString, date, dtf);
    }

    /**
     * Asserts that two dates are equal.
     * @param expectedDateAsString date formatted as "yyyyMMdd HH:mm"
     * @param date actual date
     * @throws IllegalArgumentException if <code>expectedDateAsString</code> is not a valid date format
     */
    public static void dateTimeEqual(String expectedDateAsString, Calendar date) throws IllegalArgumentException
    {
        performComparison(expectedDateAsString, date.getTime(), dtf);
    }

}
