/**
 *
 * Openutils testing library (http://lab.openmindonline.it/products/testing.html)
 * Framework that helps to simplify unit testing coding
 * Copyright (C)2005 - 2009, Openmind S.r.l. http://www.openmindonline.it
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/lgpl-2.1.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package it.openutils.testing;

import it.openutils.testing.dbunit.DatasetType;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.dbunit.dataset.datatype.DefaultDataTypeFactory;
import org.dbunit.dataset.datatype.IDataTypeFactory;
import org.dbunit.operation.DatabaseOperation;


/**
 * @author fgiust
 * @version $Id: DbUnitExecution.java 1301 2009-08-25 09:41:04Z mmunaretto $
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
@Inherited
@Documented
public @interface DbUnitExecution {

    /**
     * The resource locations to use for loading dbunit dataset.
     */
    String[] datasets() default {

    };

    /**
     * The name of the datasource to use. If can be left unset only if there is only one DataSource available in the
     * Spring context.
     */
    String dataSource() default "";

    /**
     * Db schema name that will be given to dbUnit. Can be left unset if not needed (database specific)
     */
    String schema() default "";

    /**
     * The datatype factory (DatabaseConfig.PROPERTY_DATATYPE_FACTORY) to use. Can be left unset if not needed.
     */
    Class< ? extends IDataTypeFactory> dataTypeFactory() default DefaultDataTypeFactory.class;

    /**
     * A regexp that can match table names. Any table matching this regular expression will not be considered by DbUnit.
     * By default tables starting with BIN$ are ignored (oracle recycle bin).
     */
    String excludedTables() default "^BIN\\$(.*)"; // oracle recycle bin

    /**
     * If true, <strong>all</strong> the tables in the database will be truncated before loading any dataset.
     */
    boolean truncateAll() default true;

    /**
     * The database operation that will be used to truncate tables. Defaults to org.dbunit.operation.DeleteAllOperation
     */
    Class< ? extends DatabaseOperation> truncateOperation() default org.dbunit.operation.DeleteAllOperation.class;

    /**
     * The database operation that will be used to load datasets. Defaults to org.dbunit.operation.InsertOperation. For
     * Sql Server databases the default is automatically set to MsSqlIndentityInsertOperation (allow writing of identity
     * columns).
     */
    Class< ? extends DatabaseOperation> insertOperation() default org.dbunit.operation.InsertOperation.class;

    /**
     * The type of dataset to load. Defautils to XML, but automatically switches to EXCEL if you are using a file with
     * the ".xml" extension. You need to explicitely set this only if you are using the "flat xml" format.
     */
    DatasetType datasetType() default DatasetType.XML;

    /**
     * A list of dbunit features that should be enabled or disabled on the connection. See
     * http://www.dbunit.org/properties.html.
     */
    DbUnitFeature[] features() default {};

    /**
     * A list of dbunit properties that should be set on the connection. See http://www.dbunit.org/properties.html.
     */
    DbUnitProperty[] properties() default {};

}