/**
 *
 * Openutils testing library (http://lab.openmindonline.it/products/testing.html)
 * Framework that helps to simplify unit testing coding
 * Copyright (C)2005 - 2009, Openmind S.r.l. http://www.openmindonline.it
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/lgpl-2.1.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package it.openutils.testing;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;


/**
 * @author fgiust
 * @version $Id: TestUtils.java 1301 2009-08-25 09:41:04Z mmunaretto $
 */
public final class TestUtils
{

    private TestUtils()
    {
    }

    /**
     * Create a new set with all the elements.
     * @param <T> the type of the elements. Also used to allocate the set.
     * @param elements to put in the set.
     * @return new allocated set.
     */
    public static <T> Set<T> setWith(T... elements)
    {
        Set<T> newSet = new HashSet<T>(elements.length);
        for (T element : elements)
        {
            newSet.add(element);
        }
        return newSet;
    }

    /**
     * Create a new list with all the elements.
     * @param <T> the type of the elements. Also used to allocate the list.
     * @param elements to put in the list.
     * @return new allocated list.
     */
    public static <T> List<T> listWith(T... elements)
    {
        List<T> newList = new ArrayList<T>(elements.length);
        for (T element : elements)
        {
            newList.add(element);
        }
        return newList;
    }
}
