/**
 *
 * Openutils testing library (http://lab.openmindonline.it/products/testing.html)
 * Framework that helps to simplify unit testing coding
 * Copyright (C)2005 - 2009, Openmind S.r.l. http://www.openmindonline.it
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/lgpl-2.1.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
package it.openutils.testing.dbunit;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;

import org.dbunit.DatabaseUnitException;
import org.dbunit.database.IDatabaseConnection;
import org.dbunit.dataset.IDataSet;
import org.dbunit.operation.AbstractOperation;
import org.dbunit.operation.DatabaseOperation;
import org.dbunit.operation.ExclusiveTransactionException;


/**
 * Extended operation for dbunit that disables FK checks.
 * @author fgiust
 * @version $Id: MySqlAbstractNoFkOperation.java 1301 2009-08-25 09:41:04Z mmunaretto $
 */
public class MySqlAbstractNoFkOperation extends AbstractOperation
{

    /**
     * Wrapped operation.
     */
    private final DatabaseOperation operation;

    /**
     * Creates a new InsertIdentityOperation object that decorates the specified operation.
     * @param operation wrapped operation
     */
    public MySqlAbstractNoFkOperation(DatabaseOperation operation)
    {
        this.operation = operation;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void execute(IDatabaseConnection connection, IDataSet dataSet) throws DatabaseUnitException, SQLException
    {
        Connection jdbcConnection = connection.getConnection();
        Statement statement = jdbcConnection.createStatement();

        try
        {
            if (!jdbcConnection.getAutoCommit())
            {
                throw new ExclusiveTransactionException();
            }
            jdbcConnection.setAutoCommit(false);

            // disable FK
            statement.execute("SET FOREIGN_KEY_CHECKS=0");

            try
            {
                operation.execute(connection, connection.createDataSet());
            }
            finally
            {
                // enable FK
                statement.execute("SET FOREIGN_KEY_CHECKS=1");
                jdbcConnection.commit();
            }

        }
        finally
        {
            jdbcConnection.setAutoCommit(true);
            statement.close();
        }
    }
}
